@@ -3,17 +3,22 @@ require_relative 'coverage_helper'
 $LOAD_PATH.unshift File.expand_path('../../lib', __FILE__)
 
 require_relative  '../lib/tilt'
+Tilt.extract_fixed_locals = true
 
 ENV['MT_NO_PLUGINS'] = '1' # Work around stupid autoloading of plugins
 require 'minitest/autorun'
-require 'minitest/mock'
 
 if $VERBOSE
   begin
     require 'warning'
   rescue LoadError
   else
-    Warning.ignore(%r{lib/wikicloth/extensions/|lib/pdf/reader/font.rb|lib/maruku/|lib/creole/parser.rb|lib/commonmarker})
+    # Ignore spurious frozen string literal errors.  Both of these check
+    # that the string is frozen, and duplicate it.  This results in a
+    # spurious warning on Ruby 3.4, which defaults to chilled strings
+    # You need to use String#+@ to avoid this warning.  However, they
+    # will work when Ruby does decide to actually freeze literal strings.
+    Warning.ignore(%r{lib/temple/filters/encoding})
   end
 end
 
@@ -82,4 +87,17 @@ class Minitest::Spec
   ensure
     $VERBOSE = verbose
   end
+
+  def self.without_extract_fixed_locals(*a, &block)
+    it(*a){without_extract_fixed_locals{instance_exec(&block)}}
+  end
+
+  def without_extract_fixed_locals
+    begin
+      Tilt.extract_fixed_locals = false
+      yield
+    ensure
+      Tilt.extract_fixed_locals = true
+    end
+  end
 end
