@@ -1,10 +1,16 @@
-require 'test_helper'
-require 'tilt'
+require_relative 'test_helper'
 
-class TiltCacheTest < Minitest::Test
-  setup { @cache = Tilt::Cache.new }
+describe 'Tilt::Cache' do
+  before do
+    begin
+      verbose, $VERBOSE = $VERBOSE, nil
+      @cache = Tilt::Cache.new
+    ensure
+      $VERBOSE = verbose
+    end
+  end
 
-  test "caching with single simple argument to #fetch" do
+  it "caching with single simple argument to #fetch" do
     template = nil
     result = @cache.fetch('hello') { template = Tilt::StringTemplate.new {''} }
     assert_same template, result
@@ -12,7 +18,7 @@ class TiltCacheTest < Minitest::Test
     assert_same template, result
   end
 
-  test "caching with multiple complex arguments to #fetch" do
+  it "caching with multiple complex arguments to #fetch" do
     template = nil
     result = @cache.fetch('hello', {:foo => 'bar', :baz => 'bizzle'}) { template = Tilt::StringTemplate.new {''} }
     assert_same template, result
@@ -20,7 +26,18 @@ class TiltCacheTest < Minitest::Test
     assert_same template, result
   end
 
-  test "clearing the cache with #clear" do
+  it "caching nil" do
+    called = false
+    result = @cache.fetch("blah") {called = true; nil}
+    assert_equal true, called
+    assert_nil result
+    called = false
+    result = @cache.fetch("blah") {called = true; :blah}
+    assert_equal false, called
+    assert_nil result
+  end
+
+  it "clearing the cache with #clear" do
     template, other = nil
     result = @cache.fetch('hello') { template = Tilt::StringTemplate.new {''} }
     assert_same template, result
